@@ -5,8 +5,8 @@
 ;; Author: Artur Yaroshenko <artawower@protonmail.com>
 ;; URL: https://github.com/artawower/file-info.el
 ;; Package-Requires: ((emacs "28.1") (hydra "0.15.0") (browse-at-remote "0.15.0"))
-;; Package-Version: 20250930.920
-;; Package-Revision: ac8c0fecde94
+;; Package-Version: 20251107.1738
+;; Package-Revision: 5d8c5158a57e
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -652,9 +652,12 @@
   (interactive "r")
   (let* ((len (- end beg))
          (approx (ceiling (/ (float len) 4.0))))
-    (message "≈ %s tokens (chars: %s; rule: ~1 token / 4 chars)"
-             (file-info--abbrev-number approx)
-             (file-info--abbrev-number len))))
+    (concat "≈ "
+            (file-info--abbrev-number approx)
+            " tokens (chars: "
+            (file-info--abbrev-number len)
+            "; rule: ~1 token / 4 chars)")))
+
 
 (defun file-info--approx-token-count-buffer ()
   "Approximate token count for the whole buffer."
